@@ -11,7 +11,8 @@ import os
 import time
 
 # プロジェクトルートへのパスを追加
-sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..', '..', 'python'))
+sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..', '..',
+                                'python'))
 
 import numpy as np
 from scipy import sparse
@@ -21,7 +22,8 @@ from rk4_sparse import rk4_sparse_py, rk4_sparse_eigen
 savepath = os.path.join(os.path.dirname(os.path.dirname(__file__)), 'figures')
 os.makedirs(savepath, exist_ok=True)
 
-def create_ho_matrices(n_levels: int, omega: float = 1.0, hbar: float = 1.0, mu0: float = 1.0):
+def create_ho_matrices(n_levels: int, omega: float = 1.0, hbar: float = 1.0,
+                        mu0: float = 1.0):
     """調和振動子のハミルトニアンと双極子モーメント行列を生成
 
     Parameters
@@ -41,11 +43,11 @@ def create_ho_matrices(n_levels: int, omega: float = 1.0, hbar: float = 1.0, mu0
     """
     # エネルギー固有値
     energies = hbar * omega * (np.arange(n_levels) + 0.5)
-    
+
     # ハミルトニアン（対角行列）
     H0 = sparse.diags(energies, format='csr')
     H0 = H0.tocsr()  # 確実にCSR形式に変換
-    
+
     # 双極子モーメント（隣接準位間の遷移のみ）
     # <n|μ|n+1> ∝ √(n + 1)
     dipole_elements = np.sqrt(np.arange(1, n_levels)) * mu0
@@ -53,14 +55,15 @@ def create_ho_matrices(n_levels: int, omega: float = 1.0, hbar: float = 1.0, mu0
     mux = sparse.diags(dipole_elements, 1, format='csr')
     mux = mux + mux.T  # エルミート共役を加える
     mux = mux.tocsr()  # 確実にCSR形式に変換
-    
+
     # y方向の双極子モーメントは0
     muy = sparse.csr_matrix((n_levels, n_levels))
     # muy = np.zeros_like(mux)
-    
+
     return H0, mux, muy
 
-def create_gaussian_pulse(t: np.ndarray, omega_L: float, t0: float, sigma: float, amplitude: float):
+def create_gaussian_pulse(t: np.ndarray, omega_L: float, t0: float,
+                          sigma: float, amplitude: float):
     """ガウシアンパルスを生成
 
     Parameters
@@ -81,39 +84,40 @@ def create_gaussian_pulse(t: np.ndarray, omega_L: float, t0: float, sigma: float
     """
     return amplitude * np.exp(-(t - t0)**2 / (2 * sigma**2)) * np.sin(omega_L * t)
 
+
 def main():
     # パラメータ設定
     n_levels = 10  # 準位数
     omega = 10.0    # 角振動数
     hbar = 1.0     # プランク定数
     mu0 = 1.0      # 双極子モーメント
-    
+
     # パルスパラメータ
     sigma = 5.0
     amplitude = 1
     omega_L = omega
-    
+
     # 時間パラメータ
     dt = 0.001
     t_max = sigma * 10
     t0 = t_max / 2
     t = np.arange(0, t_max, dt)
     steps = len(t)
-    
+
     # 行列の生成
     H0, mux, muy = create_ho_matrices(n_levels, omega, hbar, mu0)
-    
+
     # パルスの生成
     Ex = create_gaussian_pulse(t, omega_L, t0, sigma, amplitude)
     Ey = np.zeros_like(Ex)  # y方向の電場は0
-    
+
     # 初期状態（基底状態）
     psi0 = np.zeros(n_levels, dtype=np.complex128)
     psi0[0] = 1.0
-    
+
     # シミュレーションパラメータ
     stride = 10  # 出力間隔
-    
+
     print("=== Simulation Parameters ===")
     print(f"Number of levels: {n_levels}")
     print(f"Time step: {dt:.3f}")
@@ -121,7 +125,7 @@ def main():
     print(f"Pulse center: {t0:.1f}")
     print(f"Pulse width: {sigma:.1f}")
     print(f"Pulse amplitude: {amplitude:.3f}")
-    
+
     # Python実装での計算
     print("\nRunning Python implementation...")
     start_time = time.time()
@@ -136,7 +140,7 @@ def main():
     )
     py_time = time.time() - start_time
     print(f"Python implementation time: {py_time:.3f} seconds")
-    
+
     # C++実装での計算
     print("\nRunning C++ implementation...")
     start_time = time.time()
@@ -152,14 +156,14 @@ def main():
     cpp_time = time.time() - start_time
     print(f"C++ implementation time: {cpp_time:.3f} seconds")
     print(f"Speed-up ratio: {py_time/cpp_time:.1f}x")
-    
+
     # 結果の可視化
     t_plot = t[::stride*2]  # strideに合わせて時間配列を間引く
     populations_py = np.abs(result_py)**2
     populations_cpp = np.abs(result_cpp)**2
-    
+
     plt.figure(figsize=(12, 8))
-    
+
     # Python実装の結果
     plt.subplot(2, 1, 1)
     for n in range(n_levels):
@@ -169,7 +173,7 @@ def main():
     plt.ylabel('Population')
     plt.grid(True)
     plt.legend()
-    
+
     # C++実装の結果
     plt.subplot(2, 1, 2)
     for n in range(n_levels):
@@ -179,20 +183,20 @@ def main():
     plt.ylabel('Population')
     plt.grid(True)
     plt.legend()
-    
+
     plt.tight_layout()
     plt.savefig(os.path.join(savepath, 'harmonic_oscillator_results.png'))
     plt.close()
-    
+
     # 実装間の差の確認
     max_diff = np.max(np.abs(populations_py - populations_cpp))
     print(f"\nMaximum difference between implementations: {max_diff:.2e}")
-    
+
     # エネルギー期待値の計算と保存の確認
     energies = hbar * omega * (np.arange(n_levels) + 0.5)
     E_py = np.sum(populations_py * energies[None, :], axis=1)
     E_cpp = np.sum(populations_cpp * energies[None, :], axis=1)
-    
+
     plt.figure(figsize=(10, 6))
     plt.plot(t_plot[:populations_py.shape[0]], E_py, label='Python')
     plt.plot(t_plot[:populations_cpp.shape[0]], E_cpp, '--', label='C++')
@@ -203,7 +207,7 @@ def main():
     plt.legend()
     plt.savefig(os.path.join(savepath, 'harmonic_oscillator_energy.png'))
     plt.close()
-    
+
     # パルス波形の表示
     plt.figure(figsize=(10, 6))
     plt.plot(t, Ex, label='Ex')
@@ -215,5 +219,6 @@ def main():
     plt.savefig(os.path.join(savepath, 'harmonic_oscillator_pulse.png'))
     plt.close()
 
+
 if __name__ == '__main__':
-    main() 
\ No newline at end of file
+    main()
